"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _reactRouter = require("react-router");

var _getRoutesMap = _interopRequireDefault(require("../../getRoutesMap"));

var _Link = _interopRequireDefault(require("../Link"));

var Link = (0, _reactRouter.withRouter)(_Link.default);

var LoadableComponent = function LoadableComponent() {
  return _react.default.createElement("div", null);
};

LoadableComponent.preload = function () {
  return {
    then: function then(fn) {
      return fn && fn();
    }
  };
};

var testRoutes = [{
  name: 'home',
  path: '/',
  exact: true,
  component: LoadableComponent
}, {
  name: 'customers',
  path: '/customers.html',
  exact: true,
  routes: [{
    name: 'aboutUs',
    path: '/about-us.html',
    exact: true
  }, {
    name: 'career',
    path: '/career.html',
    exact: true
  }, {
    name: 'faq',
    path: '/faq.html',
    exact: true
  }, {
    name: 'cgu',
    path: '/CGU.html',
    exact: true
  }, {
    name: 'confidentiality',
    path: '/Confidentiality.html',
    exact: true
  }, {
    name: 'cookies',
    path: '/cookies.html',
    exact: true
  }]
}, {
  name: 'notFound',
  path: '/404.html',
  component: function component() {
    return _react.default.createElement("div", null);
  }
}, {
  name: 'notFoundRedirect',
  from: '*',
  to: '/404.html'
}];
var routesMap = (0, _getRoutesMap.default)(testRoutes);

var ctx = _react.default.createContext();

var ContextProvider = function ContextProvider(props) {
  return _react.default.createElement(ctx.Provider, (0, _extends2.default)({}, props, {
    value: {
      routes: testRoutes
    }
  }));
};

var ContextConsumer = ctx.Consumer;

var badCtx = _react.default.createContext();

var BadContextProvider = function BadContextProvider(props) {
  return _react.default.createElement(badCtx.Provider, (0, _extends2.default)({}, props, {
    value: {
      routes: null
    }
  }));
};

var BadContextConsumer = badCtx.Consumer;

var renderComponent = function renderComponent(_ref) {
  var to = _ref.to,
      rest = (0, _objectWithoutProperties2.default)(_ref, ["to"]);
  return (0, _enzyme.mount)(_react.default.createElement(_reactRouter.MemoryRouter, {
    initialEntries: [to]
  }, _react.default.createElement(ContextProvider, null, _react.default.createElement(Link, (0, _extends2.default)({
    to: to
  }, rest)))));
};

describe('<Link />', function () {
  it('should shallow a <Link /> tag', function () {
    var renderedComponent = (0, _enzyme.shallow)(_react.default.createElement(Link, null));
    expect(renderedComponent.length).toBe(1);
  });
  it('should mount a <Link /> tag', function () {
    var renderedComponent = renderComponent({
      routes: testRoutes,
      routesMap: routesMap,
      to: '/404.html'
    });
    expect(renderedComponent.find('a').length).toBe(1);
    expect(renderedComponent.find('a').props().href).toBe('/404.html');
  });
  it('should getComponent with params and found the component', function () {
    var renderedComponent = renderComponent({
      routes: [{
        path: '/users/:id/service/:name',
        component: function component() {
          return _react.default.createElement("div", null, "Found");
        }
      }],
      to: '/users/4564/service/this-is_cool'
    });
    var link = renderedComponent.find('Link');
    expect(link.instance().getComponent(link.prop('to'), link.prop('routes'))()).toEqual(_react.default.createElement("div", null, "Found"));
  });
  it('should fail to getComponent', function () {
    var renderedComponent = renderComponent({
      routes: [{
        path: '/users/:id/service/:name',
        component: function component() {
          return _react.default.createElement("div", null, "Found");
        }
      }],
      to: 'users/4564/service/this-is_cool'
    });
    var link = renderedComponent.find('Link');
    expect(link.instance().getComponent(link.prop('to'), link.prop('routes'))).toBe(undefined);
  });
  it('should also fail to getComponent', function () {
    var renderedComponent = renderComponent({
      routes: [{
        path: 'users/:id/service/:name',
        component: function component() {
          return _react.default.createElement("div", null, "Found");
        }
      }],
      to: '/users/4564/service/this-is_cool'
    });
    var link = renderedComponent.find('Link');
    expect(link.instance().getComponent(link.prop('to'), link.prop('routes'))).toBe(undefined);
  });
  it('should also fail to getComponent', function () {
    var renderedComponent = renderComponent({
      to: '/users/4564/service/this-is_cool'
    });
    var link = renderedComponent.find('Link');
    expect(link.instance().getComponent(link.prop('to'), link.prop('routes'))).toBe(undefined);
  });
  it('should onMouseOver', function () {
    var spy = jest.fn();
    var renderedComponent = renderComponent({
      routes: testRoutes,
      to: '/404.html',
      onMouseOver: spy
    });
    renderedComponent.simulate('mouseover');
    expect(spy).toHaveBeenCalled();
  });
  it('should onPreload and onLoaded onMouseOver', function () {
    var spy = jest.fn();
    var spyOnLoaded = jest.fn();
    var renderedComponent = renderComponent({
      routes: testRoutes,
      to: '/',
      onPreload: spy,
      onLoaded: spyOnLoaded
    });
    renderedComponent.simulate('mouseover');
    expect(spy).toHaveBeenCalled();
    expect(spyOnLoaded).toHaveBeenCalled();
  });
  it('should onMouseOver with preload', function () {
    var renderedComponent = renderComponent({
      routes: testRoutes,
      to: '/'
    });
    renderedComponent.simulate('mouseover');
    expect(renderedComponent.length).toBe(1);
  });
  it('should onLoaded onMouseOver', function () {
    var spy = jest.fn();
    var spyOnLoaded = jest.fn();
    var renderedComponent = renderComponent({
      routes: testRoutes,
      to: '/',
      onPreload: spy,
      onLoaded: spyOnLoaded
    });
    renderedComponent.simulate('mouseover');
    expect(spy).toHaveBeenCalled();
    expect(spyOnLoaded).toHaveBeenCalled();
  });
  it('should onClick onPageChange and onFocus', function () {
    var spy = jest.fn();
    var spyPageChange = jest.fn();
    var spyFocus = jest.fn();
    var renderedComponent = renderComponent({
      routes: testRoutes,
      to: '/404.html',
      onClick: spy,
      onPageChange: spyPageChange,
      onFocus: spyFocus
    });
    renderedComponent.simulate('click');
    expect(spy).toHaveBeenCalled();
    expect(spyPageChange).toHaveBeenCalled();
    renderedComponent.find('a').prop('onFocus')();
    expect(spyFocus).toHaveBeenCalled();
  });
  it('should onPageChange', function () {
    var spy = jest.fn();
    var renderedComponent = renderComponent({
      routes: testRoutes,
      to: '/404.html',
      onPageChange: spy
    });
    renderedComponent.simulate('click');
    expect(spy).toHaveBeenCalled();
  });
  it('should onBeforePageChange', function () {
    var spy = jest.fn();
    var renderedComponent = renderComponent({
      routes: testRoutes,
      to: '/404.html',
      onBeforePageChange: spy
    });
    renderedComponent.simulate('click');
    expect(spy).toHaveBeenCalled();
  });
  it('should onLoaded', function () {
    var spy = jest.fn();
    var renderedComponent = renderComponent({
      waitChunk: true,
      routes: testRoutes,
      to: '/',
      onLoaded: spy
    });
    renderedComponent.simulate('click');
    expect(spy).toHaveBeenCalled();
  });
  it('should waitChunk and onPreload onClick', function () {
    var spy = jest.fn();
    var spyPageChange = jest.fn();
    var spyLoaded = jest.fn();
    var renderedComponent = renderComponent({
      routes: testRoutes,
      to: '/',
      onPreload: spy,
      onPageChange: spyPageChange,
      onLoaded: spyLoaded,
      waitChunk: true
    });
    renderedComponent.simulate('click');
    expect(spy).toHaveBeenCalled();
  });
  it('should waitChunk and onPreload onClick with routesMap', function (done) {
    var spy = jest.fn();
    var spyPageChange = jest.fn();
    var spyLoaded = jest.fn();
    var renderedComponent = renderComponent({
      routesMap: routesMap,
      to: '/',
      onPreload: spy,
      onPageChange: spyPageChange,
      onLoaded: spyLoaded,
      waitChunk: true
    });
    renderedComponent.simulate('click');
    expect(spy).toHaveBeenCalled();
    done();
  });
  it('should waitChunk onClick', function () {
    var renderedComponent = renderComponent({
      routes: testRoutes,
      to: '/',
      waitChunk: true
    });
    renderedComponent.simulate('click');
    expect(renderedComponent.length).toEqual(1);
  });
  it('should renderWith a ContextConsumer', function () {
    var spy = jest.fn();
    var spyPageChange = jest.fn();
    var spyLoaded = jest.fn();
    var spyFocus = jest.fn();
    var spyMouseover = jest.fn();
    var renderedComponent = renderComponent({
      to: '/',
      onPreload: spy,
      onPageChange: spyPageChange,
      onLoaded: spyLoaded,
      onFocus: spyFocus,
      onMouseOver: spyMouseover,
      waitChunk: true,
      ContextConsumer: ContextConsumer
    });
    renderedComponent.find('a').simulate('click');
    expect(spy).toHaveBeenCalled();
    renderedComponent.find('a').prop('onFocus')();
    expect(spyFocus).toHaveBeenCalled();
    renderedComponent.find('a').simulate('mouseover');
    expect(spyMouseover).toHaveBeenCalled();
  });
  it('should throw error due to bad ContextConsumer', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_reactRouter.MemoryRouter, {
      initialEntries: ['/']
    }, _react.default.createElement(BadContextProvider, null, _react.default.createElement(Link, {
      to: "/",
      ContextConsumer: BadContextConsumer
    }))));
    expect(renderedComponent.length).toBe(1);
  });
  it('should throw warning due to both routes and ContextConsumer', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_reactRouter.MemoryRouter, {
      initialEntries: ['/']
    }, _react.default.createElement(ContextProvider, null, _react.default.createElement(Link, {
      to: "/",
      routes: testRoutes,
      ContextConsumer: ContextConsumer
    }))));
    expect(renderedComponent.length).toBe(1);
  });
  it('should skip preload on mouse over and onClick', function () {
    var onPreLoad = jest.fn();
    var onLoaded = jest.fn();
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_reactRouter.MemoryRouter, {
      initialEntries: ['/']
    }, _react.default.createElement(ContextProvider, null, _react.default.createElement(Link, {
      to: "/",
      routes: testRoutes,
      ContextConsumer: ContextConsumer,
      preload: false,
      onPreload: onPreLoad,
      onLoaded: onLoaded
    }))));
    renderedComponent.find('a').simulate('mouseover');
    expect(onPreLoad).not.toHaveBeenCalled();
    renderedComponent.find('a').simulate('click');
    expect(onLoaded).not.toHaveBeenCalled();
  });
  it('should onClick with delay', function () {
    var onClick = jest.fn();
    var onPageChange = jest.fn();
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_reactRouter.MemoryRouter, {
      initialEntries: ['/']
    }, _react.default.createElement(ContextProvider, null, _react.default.createElement(Link, {
      to: "/",
      routes: testRoutes,
      ContextConsumer: ContextConsumer,
      preload: true,
      delay: 200,
      onClick: onClick,
      onPageChange: onPageChange
    }))));
    renderedComponent.find('a').simulate('click');
    expect(onClick).toHaveBeenCalled();
    setTimeout(function () {
      expect(onPageChange).toHaveBeenCalled();
    }, 250);
  }, 300);
  it('should onClick with delay as a function', function () {
    var onClick = jest.fn();
    var onPageChange = jest.fn();
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_reactRouter.MemoryRouter, {
      initialEntries: ['/']
    }, _react.default.createElement(ContextProvider, null, _react.default.createElement(Link, {
      to: "/",
      routes: testRoutes,
      ContextConsumer: ContextConsumer,
      preload: true,
      delay: function delay() {
        return 200;
      },
      onClick: onClick,
      onPageChange: onPageChange
    }))));
    renderedComponent.find('a').simulate('click');
    expect(onClick).toHaveBeenCalled();
    setTimeout(function () {
      expect(onPageChange).toHaveBeenCalled();
    }, 250);
  }, 300);
});