"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _getPages = _interopRequireDefault(require("../getPages"));

var _getRoutesMap = _interopRequireDefault(require("../getRoutesMap"));

describe('getPages homepage with /', function () {
  it('should set home page automatically', function () {
    expect((0, _getPages.default)([{
      path: '/'
    }])).toEqual({
      home: {
        path: '/'
      }
    });
  });
  it('should use the alias for homepage when set', function () {
    var p = (0, _getPages.default)([{
      path: '/',
      page: 'newHome'
    }]);
    expect(p).toEqual({
      newHome: {
        path: '/'
      }
    });
    var p2 = (0, _getPages.default)([{
      path: '/',
      page: ['newHome', 'newHome.sub']
    }]);
    expect(p2).toEqual({
      newHome: {
        path: '/',
        sub: {
          path: '/'
        }
      }
    });
  });
});
describe('getPages', function () {
  var routes = [{
    page: 'myHello',
    path: '/hello',
    component: function component() {
      return _react.default.createElement("div", null, "hi");
    },
    routes: [{
      page: 'myWorld',
      path: '/hello/world',
      routes: [{
        page: ['2017', 'two-thousand-seventeen', 'toRoot.two-thousand-seventeen'],
        path: '/hello/world/2017'
      }]
    }]
  }, {
    path: 'homepage/resource'
  }, {
    page: 'myBye',
    path: '/bye',
    routes: [{
      page: 'myByeForest',
      path: '/bye/forest',
      routes: [{
        page: 'myGump',
        path: '/bye/forest/gump',
        routes: [{
          page: 'toRoot.my1337',
          path: '/bye/forest/gump/1337'
        }]
      }]
    }]
  }];
  var expectedPages = {
    2017: {
      path: '/hello/world/2017'
    },
    hello: {
      path: '/hello',
      world: {
        2017: {
          path: '/hello/world/2017'
        },
        path: '/hello/world'
      }
    },
    myHello: {
      path: '/hello'
    },
    myWorld: {
      path: '/hello/world'
    },
    'two-thousand-seventeen': {
      path: '/hello/world/2017'
    },
    toRoot: {
      'two-thousand-seventeen': {
        path: '/hello/world/2017'
      },
      my1337: {
        path: '/bye/forest/gump/1337'
      }
    },
    homepage: {
      resource: {
        path: 'homepage/resource'
      }
    },
    bye: {
      path: '/bye',
      forest: {
        path: '/bye/forest',
        gump: {
          1337: {
            path: '/bye/forest/gump/1337'
          },
          path: '/bye/forest/gump'
        }
      }
    },
    myBye: {
      path: '/bye'
    },
    myByeForest: {
      path: '/bye/forest'
    },
    myGump: {
      path: '/bye/forest/gump'
    }
  };
  describe('should get pages with list of routes configuration', function () {
    var p = (0, _getPages.default)(routes);
    it('should get pages', function () {
      expect(p).toEqual(expectedPages);
      expect(p.hello.routes).not.toBeDefined();
    });
    it('should remove sub routes object from pages', function () {
      expect(p.hello.routes).not.toBeDefined();
      expect(p.bye.routes).not.toBeDefined();
      expect(p.bye.forest.routes).not.toBeDefined();
    });
    it('should remove components from pages', function () {
      expect(p.hello.component).not.toBeDefined();
    });
  });
  describe('should get pages with a routes map', function () {
    var p = (0, _getPages.default)((0, _getRoutesMap.default)(routes));
    it('should get pages', function () {
      expect(p).toEqual(expectedPages);
      expect(p.hello.routes).not.toBeDefined();
    });
    it('should remove sub routes object from pages', function () {
      expect(p.hello.routes).not.toBeDefined();
      expect(p.bye.routes).not.toBeDefined();
      expect(p.bye.forest.routes).not.toBeDefined();
    });
    it('should remove components from pages', function () {
      expect(p.hello.component).not.toBeDefined();
    });
  });
});
describe('getPages', function () {
  it('should succeed all kind of merge', function () {
    var routes = [{
      from: '/user-management',
      to: '/',
      routes: [{
        page: 'userManagement.authoritiesShow',
        path: '/user-management/:resource/:id/authorities/show'
      }, {
        page: 'authoritiesEdit',
        path: '/user-management/:resource/:id/authorities'
      }, {
        path: '/user-management/users',
        menu: {
          role: 'VIEW_USER'
        }
      }, {
        path: '/user-management/organizations',
        menu: {
          role: 'VIEW_ORG'
        }
      }]
    }];
    var expectedPages = {
      userManagement: {
        authoritiesShow: {
          path: '/user-management/:resource/:id/authorities/show'
        },
        $resource: {
          $id: {
            authorities: {
              path: '/user-management/:resource/:id/authorities',
              show: {
                path: '/user-management/:resource/:id/authorities/show'
              }
            }
          }
        },
        organizations: {
          menu: {
            role: 'VIEW_ORG'
          },
          path: '/user-management/organizations'
        },
        users: {
          menu: {
            role: 'VIEW_USER'
          },
          path: '/user-management/users'
        }
      },
      authoritiesEdit: {
        path: '/user-management/:resource/:id/authorities'
      }
    };
    expect((0, _getPages.default)(routes)).toEqual(expectedPages);
    expect((0, _getPages.default)((0, _getRoutesMap.default)(routes))).toEqual(expectedPages);
  });
  it('should work', function () {
    var routesConfig = [{
      path: '/',
      page: 'dashboard'
    }, {
      path: '/users',
      routes: [{
        page: ['users.edit', 'dashboard.userEdit'],
        path: '/users/:id'
      }]
    }];
    var p = (0, _getPages.default)(routesConfig);
    expect(p.users.$id.path).toEqual('/users/:id');
    expect(p.users.edit.path).toEqual('/users/:id');
    expect(p.dashboard.userEdit.path).toEqual('/users/:id');
  });
  it('should work', function () {
    var routesConfig = [{
      path: '/test',
      role: 10
    }];
    var p = (0, _getPages.default)(routesConfig);
    expect(p.test.path).toEqual('/test');
  });
  it('should work', function () {
    var routesConfig = [{
      path: '/auth',
      role: 1
    }, {
      path: '/users'
    }];
    var p = (0, _getPages.default)(routesConfig);
    expect(p).toEqual({
      auth: {
        path: '/auth',
        role: 1
      },
      users: {
        path: '/users'
      }
    });
  });
  it('should remove duplicate', function () {
    var routesConfig = [{
      path: '/auth',
      role: 1
    }, {
      path: '/users'
    }, {
      path: '/user-management'
    }, {
      path: '/users',
      exact: true,
      routes: [{
        page: 'users.userEdit',
        path: '/users/:id'
      }]
    }];
    var p = (0, _getPages.default)(routesConfig);
    expect(p).toEqual({
      auth: {
        path: '/auth',
        role: 1
      },
      userManagement: {
        path: '/user-management'
      },
      users: {
        exact: true,
        path: '/users',
        $id: {
          path: '/users/:id'
        },
        userEdit: {
          path: '/users/:id'
        }
      }
    });
  });
  it('should remove extensions', function () {
    var routesConfig = [{
      path: '/auth.html',
      role: 1
    }, {
      path: '/users.htm'
    }];
    var p = (0, _getPages.default)(routesConfig);
    expect(p).toEqual({
      auth: {
        path: '/auth.html',
        role: 1
      },
      usersHtm: {
        path: '/users.htm'
      }
    });
  });
  it('should not remove extensions', function () {
    var routesConfig = [{
      path: '/auth.html',
      role: 1
    }, {
      path: '/users.htm'
    }];
    var p2 = (0, _getPages.default)(routesConfig, undefined, {
      extensions: []
    });
    expect(p2).toEqual({
      authHtml: {
        path: '/auth.html',
        role: 1
      },
      usersHtm: {
        path: '/users.htm'
      }
    });
  });
});