"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _makeRoutes = _interopRequireDefault(require("../makeRoutes"));

var _getRoutesMap = _interopRequireDefault(require("../getRoutesMap"));

var testRoutes = [{
  name: 'home',
  path: '/',
  exact: true
}, {
  name: 'customers',
  path: '/customers.html',
  exact: true,
  routes: [{
    name: 'aboutUs',
    path: '/about-us.html',
    exact: true
  }, {
    name: 'career',
    path: '/career.html',
    exact: true
  }, {
    name: 'faq',
    path: '/faq.html',
    exact: true
  }, {
    name: 'cgu',
    path: '/CGU.html',
    exact: true
  }, {
    name: 'confidentiality',
    path: '/Confidentiality.html',
    exact: true
  }, {
    name: 'cookies',
    path: '/cookies.html',
    exact: true
  }]
}, {
  name: 'notFound',
  path: '/404.html'
}, {
  name: 'notFoundRedirect',
  from: '*',
  to: '/404.html'
}];
describe('makeRoutes', function () {
  it('makeRoutes should return a list of <Route />', function () {
    var routeList = (0, _makeRoutes.default)(testRoutes);
    expect(routeList.length).toBe(10);
    expect(routeList.find(function (r) {
      return r.props.path === '/about-us.html';
    }).props.path).toEqual('/about-us.html');
    var routeProps = routeList.find(function (r) {
      return r.props.path === '/404.html';
    }).props;
    expect(routeProps.path).toEqual('/404.html');
  });
  it('makeRoutes should return only one copy per duplicate <Route />', function () {
    var routeList = (0, _makeRoutes.default)([{
      path: '/same'
    }, {
      path: '/same'
    }]);
    expect(routeList.length).toBe(1);
  });
  it('makeRoutes should work with Map', function () {
    var routeList = (0, _makeRoutes.default)((0, _getRoutesMap.default)(testRoutes));
    expect(routeList.length).toBe(10);
    expect(routeList.find(function (r) {
      return r.props.path === '/about-us.html';
    }).props.path).toEqual('/about-us.html');
    var routeProps = routeList.find(function (r) {
      return r.props.path === '/404.html';
    }).props;
    expect(routeProps.path).toEqual('/404.html');
  });
});